@@ -1,13 +1,17 @@
 """Bump `pyproject.toml` with changes in `requirements.txt`"""
 
-import toml
 from pathlib import Path
 
+import toml
+
 REQUIREMENTS = Path("requirements.txt")
 PYPROJECT = Path("pyproject.toml")
 
 with open(REQUIREMENTS) as file:
-    dependencies = [line.rstrip() for line in file if not line.startswith("#")]
+    dependencies = [
+        line.rstrip() for line in file if line != "\n" and not line.startswith("#")
+    ]
+
 
 with open(PYPROJECT) as file:
     content = toml.load(file)
