@@ -1,5 +1,3 @@
-"""Get material properties."""
-
 import pandas as pd
 from numpy import typing as npt
 from scipy.interpolate import interp1d
@@ -7,6 +5,8 @@ from scipy.interpolate import interp1d
 from propshop.configs import config
 from propshop.library import Mat, Prop
 
+__all__ = ["get_prop", "get_interp", "get_relationship_from_table"]
+
 TEMP = "TEMPERATURE"
 
 
@@ -22,6 +22,6 @@ def get_interp(mat: Mat, prop: Prop):
 
 def get_relationship_from_table(mat: Mat, prop: Prop) -> pd.DataFrame:
     return pd.read_feather(
-        config.tables / f"{mat.name}.feather",  # type: ignore
+        config.tables / f"{mat.name}.feather",
         columns=[TEMP, prop.name],
     ).dropna()
